LiquidGlassContainer class

Inheritance

Constructors

LiquidGlassContainer({Key? key, Widget? child, double? width, double? height, double? borderRadius = 10.0, EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 30, vertical: 40), required GlobalKey<State<StatefulWidget>> backgroundKey, Color? shadowColor, double shadowBlurRadius = 40.0, double shadowSpreadRadius = 5.0, double shadowOffset = 30.0, Color color = Colors.transparent, double smoothness = 1, double refraction = 0.97, double chromaticDispersion = 0.01, double distortionStrength = 0.8, double distortionSlope = -0.5})
const

Properties

backgroundKey GlobalKey<State<StatefulWidget>>
final
borderRadius double?
final
child Widget?
子组件
final
chromaticDispersion double
色散系数
final
color Color
玻璃颜色
final
distortionSlope double
扭曲坡度
final
distortionStrength double
扭曲强度
final
hashCode int
The hash code for this object.
no setterinherited
height double?
容器高度
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
内边距
final
refraction double
缩放/折射系数
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowBlurRadius double
阴影模糊半径
final
shadowColor Color?
阴影颜色
final
shadowOffset double
阴影距离
final
shadowSpreadRadius double
阴影扩散半径
final
smoothness double
圆角平滑度
final
width double?
容器宽度
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<LiquidGlassContainer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited